.. _changelog:

Changelog
=========

0.4.3
-----

 * Fixes to `helpers.bulk_index`, better error handling
 * More benevolent `hosts` argument parsing for `Elasticsearch`
 * `requests` no longer required (nor recommended) for install

0.4.2
-----
 
 * `ignore` param acceted by all APIs
 * Fixes to `helpers.bulk_index`

0.4.1
-----

Initial release.
